@@ -36,6 +36,12 @@ from urllib3.exceptions import MaxRetryError
 class KfpPipelineProcessor(PipelineProcessor):
     _type = 'kfp'
 
+    # Provide users with the ability to identify a writable directory in the
+    # running container where the notebook | script is executed. The location
+    # must exist and be known before the container is started.
+    # Defaults to `/tmp`
+    WCD = os.getenv('ELYRA_WRITABLE_CONTAINER_DIR', '/tmp').strip().rstrip('/')
+
     @property
     def type(self):
         return self._type
@@ -50,6 +56,8 @@ class KfpPipelineProcessor(PipelineProcessor):
         cos_endpoint = runtime_configuration.metadata['cos_endpoint']
         cos_bucket = runtime_configuration.metadata['cos_bucket']
 
+        user_namespace = runtime_configuration.metadata.get('user_namespace')
+
         # TODO: try to encapsulate the info below
         api_username = runtime_configuration.metadata.get('api_username')
         api_password = runtime_configuration.metadata.get('api_password')
@@ -99,7 +107,10 @@ class KfpPipelineProcessor(PipelineProcessor):
                 else:
                     raise lve
 
-            run = client.run_pipeline(experiment_id=client.create_experiment(pipeline_name).id,
+            experiment = client.create_experiment(name=pipeline_name,
+                                                  namespace=user_namespace)
+
+            run = client.run_pipeline(experiment_id=experiment.id,
                                       job_name=timestamp,
                                       pipeline_id=kfp_pipeline.id)
 
@@ -166,7 +177,8 @@ class KfpPipelineProcessor(PipelineProcessor):
             python_output = template.render(operations_list=defined_pipeline,
                                             pipeline_name=pipeline_name,
                                             api_endpoint=api_endpoint,
-                                            pipeline_description=description)
+                                            pipeline_description=description,
+                                            writable_container_dir=self.WCD)
 
             # Write to python file and fix formatting
             with open(absolute_pipeline_export_path, "w") as fh:
@@ -234,6 +246,9 @@ class KfpPipelineProcessor(PipelineProcessor):
             pipeline_envs['AWS_SECRET_ACCESS_KEY'] = cos_password
             # Convey pipeline logging enablement to operation
             pipeline_envs['ELYRA_ENABLE_PIPELINE_INFO'] = str(self.enable_pipeline_info)
+            # Setting identifies a writable directory in the container image.
+            # Only Unix-style path spec is supported.
+            pipeline_envs['ELYRA_WRITABLE_CONTAINER_DIR'] = self.WCD
 
             if operation.env_vars:
                 for env_var in operation.env_vars:
@@ -255,7 +270,15 @@ class KfpPipelineProcessor(PipelineProcessor):
                                                     pipeline_outputs=operation.outputs,
                                                     pipeline_envs=pipeline_envs,
                                                     emptydir_volume_size=emptydir_volume_size,
-                                                    image=operation.runtime_image)
+                                                    image=operation.runtime_image,
+                                                    file_outputs={
+                                                        'mlpipeline-metrics':
+                                                            '{}/mlpipeline-metrics.json'
+                                                            .format(pipeline_envs['ELYRA_WRITABLE_CONTAINER_DIR']),
+                                                        'mlpipeline-ui-metadata':
+                                                            '{}/mlpipeline-ui-metadata.json'
+                                                            .format(pipeline_envs['ELYRA_WRITABLE_CONTAINER_DIR'])
+                                                    })
 
             self.log_pipeline_info(pipeline_name,
                                    f"processing operation dependencies for id: {operation.id}",
